/**********************************************************

Spore API Library for Processing
Created by Michael Twardos on  2/18/2009

Use this along side of processing_spore_api.pde  to test out the API methods.
More info can be found at: http://www.spore.com/comm/developer
**********************************************************/

/* Geenral method for calling a url of xml data */
XMLElement getRestService(String url)
{  
  try{
    XMLElement xml = new XMLElement(this, url);
      return xml;
  }catch(Exception e)
  {
      XMLElement xml = new XMLElement();
      return xml;
  }
} 
/* Recent and total users and assets uploaded*/
String[] getStats(){
  XMLElement xml = getRestService("http://www.spore.com/rest/stats" );
  String[] userInfo = new String[4];
  userInfo[0] = xml.getChild("totalUploads").getContent(); 
  userInfo[1] = xml.getChild("dayUploads").getContent(); 
  userInfo[2] = xml.getChild("totalUsers").getContent(); 
  userInfo[3] = xml.getChild("dayUsers").getContent(); 
  return userInfo; 
}
/* Get basic info about a user*/
String[] getUserInfo(String user){
  XMLElement xml = getRestService("http://www.spore.com/rest/user/" + user );
  String[] userInfo = new String[5];
  userInfo[0] = xml.getChild("input").getContent(); 
  userInfo[1] = xml.getChild("id").getContent(); 
  userInfo[2] = xml.getChild("image").getContent(); 
  userInfo[3] = xml.getChild("tagline").getContent(); 
  userInfo[4] = xml.getChild("creation").getContent(); 
  return userInfo; 
}
/* Get teh buddies of a given user */
String[][] getBuddiesPerUser(String user, String start, String lengt){
  XMLElement xml = getRestService("http://www.spore.com/rest/users/buddies/" + user + "/" + start + "/" + lengt );
  XMLElement[] buddies = xml.getChildren("buddy");
  int L = buddies.length;
   String[][] buddyInfo = new String[L][2];
  for(int i =0; i<L; i++)
  {
  buddyInfo[i][0] = buddies[i].getChild("name").getContent();  
  buddyInfo[i][1] = buddies[i].getChild("id").getContent();
  }
  return buddyInfo; 
}
/* Get the assets from a given user*/
String[][] getAssetsPerUser(String user, String start, String lengt, String typ){
  XMLElement xml = getRestService("http://www.spore.com/rest/assets/user/" + user + "/" + start + "/" + lengt + "/" + typ);
  XMLElement[] assets = xml.getChildren("asset");
  int L = assets.length;
   String[][] assetInfo = new String[L][8];
  for(int i =0; i<L; i++)
  {
  assetInfo[i][0] = assets[i].getChild("id").getContent();  
  assetInfo[i][1] = assets[i].getChild("name").getContent();
  assetInfo[i][2] = assets[i].getChild("thumb").getContent();
  assetInfo[i][3] = assets[i].getChild("image").getContent();
  assetInfo[i][4] = assets[i].getChild("author").getContent();
  assetInfo[i][5] = assets[i].getChild("rating").getContent();
  assetInfo[i][6] = assets[i].getChild("type").getContent();
  assetInfo[i][7] = assets[i].getChild("subtype").getContent();
  }
  return assetInfo; 
}
/* Get the achievements of a given user*/
String[][] getAchievemetsPerUser(String user, String start, String lengt){
  XMLElement xml = getRestService("http://www.spore.com/rest/achievements/" + user + "/" + start + "/" + lengt);
  XMLElement[] achievements = xml.getChildren("achievement");
  int L = achievements.length;
  String[][] achievementInfo = new String[L][2];
  for(int i = 0; i < L; i++)
 { 
  achievementInfo[i][0] = achievements[i].getChild("guid").getContent();  
  achievementInfo[i][1] = achievements[i].getChild("date").getContent();  
 }
  return achievementInfo;
}
/* Get the Sporecasts subscribed to by a given user*/
String[][] getSubscribedSporecastsPerUser(String user){
  XMLElement xml = getRestService("http://www.spore.com/rest/sporecasts/" + user );
  XMLElement[] sporecasts = xml.getChildren("sporecast");
  int L = sporecasts.length;
  String[][] sporecastInfo = new String[L][8];
  for(int i = 0; i < L; i++)
 { 
  sporecastInfo[i][0] = sporecasts[i].getChild("title").getContent();  
  sporecastInfo[i][1] = sporecasts[i].getChild("id").getContent();  
  sporecastInfo[i][2] = sporecasts[i].getChild("author").getContent();  
  sporecastInfo[i][3] = sporecasts[i].getChild("updated").getContent();  
  sporecastInfo[i][4] = sporecasts[i].getChild("rating").getContent();  
  sporecastInfo[i][5] = sporecasts[i].getChild("subscriptioncount").getContent();  
  sporecastInfo[i][6] = sporecasts[i].getChild("tags").getContent();  
  sporecastInfo[i][7] = sporecasts[i].getChild("count").getContent();  
 }
  return sporecastInfo;
}
/* Get info on a particular asset*/
String[] getInfoPerAsset(String id){
  XMLElement xml = getRestService("http://www.spore.com/rest/asset/" + id );
  String[] assetInfo = new String[10];
  assetInfo[0] = xml.getChild("name").getContent();  
  assetInfo[1] = xml.getChild("author").getContent();  
  assetInfo[2] = xml.getChild("authorid").getContent();  
  assetInfo[3] = xml.getChild("created").getContent();
  assetInfo[4] = xml.getChild("description").getContent();
  assetInfo[5] = xml.getChild("tags").getContent();
  assetInfo[6] = xml.getChild("type").getContent();
  assetInfo[7] = xml.getChild("subtype").getContent();
  assetInfo[8] = xml.getChild("rating").getContent();
  return assetInfo;
}
/* Get info on the comments for a given asset*/
String[][] getCommentsPerAsset(String id, String start, String leng){
  XMLElement xml = getRestService("http://www.spore.com/rest/comments/" + id + "/" + start + "/" + leng  );
  XMLElement[] comments = xml.getChildren("comment");
  L = comments.length;
  String[][] commentInfo = new String[9][L];
  for(int i =0; i<L; i++)
  {
  commentInfo[0][i] = comments[i].getChild("message").getContent();  
  commentInfo[1][i] = comments[i].getChild("sender").getContent();
  commentInfo[2][i] = comments[i].getChild("date").getContent();
  }
  return commentInfo; 
}
/* Get the assets in a given Sporecast */
String[][] getAssetsPerSporecast(String id, String start, String leng){
  XMLElement xml = getRestService("http://www.spore.com/rest/assets/sporecast/" + id + "/" + start + "/" + leng  );
  XMLElement[] assets = xml.getChildren("asset");
  L = assets.length;
  String[][] assetInfo = new String[L][8];
  for(int i =0; i<L; i++)
  {
  assetInfo[i][0] = assets[i].getChild("id").getContent();  
  assetInfo[i][1] = assets[i].getChild("name").getContent();
  assetInfo[i][2] = assets[i].getChild("thumb").getContent();
  assetInfo[i][3] = assets[i].getChild("image").getContent();
  assetInfo[i][4] = assets[i].getChild("author").getContent();
  assetInfo[i][5] = assets[i].getChild("rating").getContent();
  assetInfo[i][6] = assets[i].getChild("type").getContent();
  assetInfo[i][7] = assets[i].getChild("subtype").getContent();
  }
  return assetInfo; 
}
/* Get assets from a given Sporepedia view:  query types = TOP_RATED, NEWEST, RANDOM etc. */

String[][] getSporepediaAssets(String query, String start, String leng, String type){
  XMLElement xml = getRestService("http://www.spore.com/rest/assets/search/" + query + "/" + start + "/" + leng + "/" + type );
  XMLElement[] assets = xml.getChildren("asset");
  L = assets.length;
  String[][] assetInfo = new String[L][9];
  for(int i =0; i<L; i++)
  {
  assetInfo[i][0] = assets[i].getChild("id").getContent();  
  assetInfo[i][1] = assets[i].getChild("name").getContent();
  assetInfo[i][2] = assets[i].getChild("thumb").getContent();
  assetInfo[i][3] = assets[i].getChild("image").getContent();
  assetInfo[i][4] = assets[i].getChild("author").getContent();
  assetInfo[i][5] = assets[i].getChild("rating").getContent();
  assetInfo[i][6] = assets[i].getChild("type").getContent();
  assetInfo[i][7] = assets[i].getChild("subtype").getContent();
  assetInfo[i][8] = assets[i].getChild("parent").getContent();
  }
  return assetInfo; 
}





